@@ -1,5 +1,10 @@
 """Shim class to not have to depend on typing module in prod."""
 import sys
+import warnings
+
+
+warnings.warn("josepy.magic_typing is deprecated and will be removed in a future release.",
+              DeprecationWarning)
 
 
 class TypingClass(object):
